(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     44162,       1292]
NotebookOptionsPosition[     39467,       1173]
NotebookOutlinePosition[     39824,       1189]
CellTagsIndexPosition[     39781,       1186]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Statistical physics problems", "Chapter",
 CellChangeTimes->{{3.7467794100763483`*^9, 
  3.746779416388546*^9}},ExpressionUUID->"7f1a0757-16f0-4c59-8af7-\
e88ba65b0135"],

Cell[CellGroupData[{

Cell["Diatomic ideal gas", "Subsection",
 CellChangeTimes->{{3.746779431556693*^9, 
  3.746779437749147*^9}},ExpressionUUID->"5aa61a2d-627a-4487-a3a9-\
41effb956b18"],

Cell[CellGroupData[{

Cell[TextData[{
 "Consider the partition function of diatomic ideal gas, Z=\[Sum](2l+1) ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "Trot"}], "/", "T"}]}], TraditionalForm]],ExpressionUUID->
  "2c6f3cdd-5af9-4350-a060-9f0b43378ccc"],
 " l(l+1)] (sum from l=0 to \[Infinity]). Compute the heat capacity \
numerically. Find its low- and high-temperature behaviour. Find its maximum."
}], "Subsubsection",
 CellChangeTimes->{{3.7467794435249662`*^9, 3.7467796251434183`*^9}, {
  3.7467797937201033`*^9, 3.746779794927183*^9}, {3.7467798570530653`*^9, 
  3.746779873325562*^9}},ExpressionUUID->"30063435-ac33-4918-a4ae-\
fbf5e02acd7c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{
   RowBox[{"T", ">", "0"}], "&&", 
   RowBox[{"Trot", ">", "0"}], "&&", 
   RowBox[{"Et", ">", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.7467804959945087`*^9, 
  3.7467805044020557`*^9}},ExpressionUUID->"f55084c2-5117-49a4-845e-\
fecbacf4fefb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"T", ">", "0"}], "&&", 
  RowBox[{"Trot", ">", "0"}], "&&", 
  RowBox[{"Et", ">", "0"}]}]], "Output",
 CellChangeTimes->{
  3.746780504941238*^9},ExpressionUUID->"b3ef5269-09e5-4d2f-85bf-\
ca4069b92a86"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", 
    RowBox[{"T_", ",", "Trot_"}], "]"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"l", "=", "0"}], "\[Infinity]"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Trot", " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}]}], "T"]}], "]"}]}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"FNum", "[", 
    RowBox[{"T_", ",", "Trot_"}], "]"}], ":=", 
   RowBox[{"-", 
    RowBox[{"Log", "[", 
     RowBox[{"NSum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], " ", 
        RowBox[{"Exp", "[", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"Trot", " ", "l", " ", 
            RowBox[{"(", 
             RowBox[{"l", "+", "1"}], ")"}]}], "T"]}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}], 
     "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.746779461384633*^9, 3.746779500138242*^9}, {
  3.746779798021056*^9, 3.7467797987428093`*^9}, {3.74677988303939*^9, 
  3.746780025431284*^9}, {3.746780060078042*^9, 3.746780086576123*^9}, {
  3.746780171604929*^9, 3.746780174323657*^9}, {3.7467802056282053`*^9, 
  3.7467802182689323`*^9}, {3.7467803929058027`*^9, 3.7467804754729443`*^9}, {
  3.746780517426826*^9, 3.746780545108553*^9}, {3.7467807083660173`*^9, 
  3.746780715958591*^9}, {3.746781042950457*^9, 
  3.74678106042141*^9}},ExpressionUUID->"26be045e-bc46-490c-9394-\
1a6939bad5e2"],

Cell["Low-T:", "Text",
 CellChangeTimes->{{3.7467805479544*^9, 
  3.746780549369945*^9}},ExpressionUUID->"aeae8beb-c612-436b-bb4c-\
468c878c5629"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Z", "[", 
    RowBox[{"T_", ",", "Trot_", ",", "m_"}], "]"}], ":=", 
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"l", "=", "0"}], "m"], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Trot", " ", "l", " ", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}]}], "T"]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Flow", "=", 
   RowBox[{
    RowBox[{"-", "T"}], " ", 
    RowBox[{"Log", "[", 
     RowBox[{"Z", "[", 
      RowBox[{"T", ",", "Trot", ",", "3"}], "]"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ulow", " ", "=", " ", 
   RowBox[{
    RowBox[{"T", "^", "2"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"Z", "[", 
        RowBox[{"T", ",", "Trot", ",", "3"}], "]"}], "]"}], ",", "T"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Series", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"Ulow", ",", "T"}], "]"}], "/.", 
          RowBox[{"T", "\[Rule]", " ", 
           RowBox[{"Trot", "/", " ", 
            RowBox[{"Log", "[", "ET", "]"}]}]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"ET", ",", "\[Infinity]", ",", "0"}], "}"}]}], "]"}], "//", 
       "Normal"}], ")"}], "//", "Simplify"}], ")"}], "/.", 
   RowBox[{"ET", "\[Rule]", " ", 
    RowBox[{"Exp", "[", 
     RowBox[{"Trot", "/", "T"}], "]"}]}]}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.746779461384633*^9, 3.746779500138242*^9}, {
  3.746779798021056*^9, 3.7467797987428093`*^9}, {3.74677988303939*^9, 
  3.746780025431284*^9}, {3.746780060078042*^9, 3.746780086576123*^9}, {
  3.746780171604929*^9, 3.746780174323657*^9}, {3.7467802056282053`*^9, 
  3.7467802182689323`*^9}, {3.7467803929058027`*^9, 3.7467804754729443`*^9}, {
  3.746780517426826*^9, 
  3.746780545108553*^9}},ExpressionUUID->"e027bd06-3372-4135-98df-\
811d3d96c0f6"],

Cell[BoxData[
 FractionBox[
  RowBox[{"12", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "Trot"}], "T"]}]], " ", 
   SuperscriptBox["Trot", "2"]}], 
  SuperscriptBox["T", "2"]]], "Output",
 CellChangeTimes->{
  3.7467799332682133`*^9, {3.746779964596848*^9, 3.746780026116894*^9}, {
   3.74678006407563*^9, 3.746780087011046*^9}, 3.746780174834154*^9, {
   3.746780206051683*^9, 3.746780220107398*^9}, {3.746780434309317*^9, 
   3.746780475793367*^9}, {3.746780507457581*^9, 
   3.746780539688178*^9}},ExpressionUUID->"926cf37b-2fa9-4808-8744-\
4f035b525702"]
}, Open  ]],

Cell["High-T:", "Text",
 CellChangeTimes->{{3.746780574723878*^9, 
  3.746780575931159*^9}},ExpressionUUID->"4c1061d1-1bff-404a-b93b-\
6a8f661a72cd"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Zhigh", "=", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "l"}], "+", "1"}], ")"}], " ", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"Trot", " ", 
          RowBox[{"l", "^", "2"}]}], "T"]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"l", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"T", "^", "2"}], " ", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Log", "[", "Zhigh", "]"}]}], "/.", 
        RowBox[{"T", "\[Rule]", " ", 
         RowBox[{"Trot", " ", "T0"}]}]}], "//", "Simplify"}], ",", 
      RowBox[{"{", 
       RowBox[{"T0", ",", "2"}], "}"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"T", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7467806245486526`*^9, 3.746780635188038*^9}, {
  3.74678093467098*^9, 
  3.746781017951231*^9}},ExpressionUUID->"e6ff56e7-94bb-4b35-819c-\
28d8d776ef86"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Pi]", "+", 
       RowBox[{"5", " ", 
        SqrtBox["\[Pi]"], " ", 
        SqrtBox["T0"]}], "+", 
       RowBox[{"8", " ", "T0"}]}], ")"}], " ", 
     SuperscriptBox["T", "2"]}], 
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SqrtBox["\[Pi]"], "+", 
        RowBox[{"2", " ", 
         SqrtBox["T0"]}]}], ")"}], "2"], " ", 
     SuperscriptBox["T0", "2"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "T"], "]"}], "2"],
    SeriesData[$CellContext`T, 
     DirectedInfinity[1], {}, -2, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`T, 
   DirectedInfinity[
   1], {((Rational[
       1, 2] (Pi^Rational[1, 2] + 
        2 $CellContext`T0^Rational[1, 2])^(-2)) $CellContext`T0^(-2)) (
     Pi + (5 Pi^Rational[1, 2]) $CellContext`T0^Rational[1, 2] + 
     8 $CellContext`T0)}, -2, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{
  3.746780653410349*^9, {3.7467809545766573`*^9, 
   3.746781018605803*^9}},ExpressionUUID->"54240b0d-0043-4bac-8d57-\
1513fc9d4eb2"]
}, Open  ]],

Cell["Maximum:", "Text",
 CellChangeTimes->{{3.746781355603752*^9, 
  3.746781356708228*^9}},ExpressionUUID->"f8c99f9f-bdf9-410d-994d-\
57a4b4aefedb"],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"T", "^", "2"}], 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"Z", "[", 
           RowBox[{"T", ",", "1", ",", "100"}], "]"}], "]"}], ",", "T"}], 
        "]"}]}], ",", "T"}], "]"}], "//", "Evaluate"}], ",", 
   RowBox[{"{", 
    RowBox[{"T", ",", "0.75", ",", "0.85"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7467811801358223`*^9, 3.746781236858979*^9}, {
  3.7467812780751753`*^9, 3.746781290891177*^9}, {3.74678134610021*^9, 
  3.7467813502999573`*^9}},ExpressionUUID->"57d36992-120a-4a5c-9213-\
ba131f3252c9"],

Cell["around T=0.807", "Text",
 CellChangeTimes->{{3.746781630369442*^9, 
  3.746781635858076*^9}},ExpressionUUID->"e62e425d-bdb7-4355-8744-\
8ff7017c9dbb"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Expanding gas", "Subsection",
 CellChangeTimes->{{3.746779431556693*^9, 3.746779437749147*^9}, {
  3.746781645634516*^9, 
  3.7467816470099077`*^9}},ExpressionUUID->"f8493287-7cd9-417b-839f-\
faf33a4095b2"],

Cell[CellGroupData[{

Cell[TextData[{
 "Consider a gas at constant density n0 inside a small sphere. The sphere is \
suddenly removed and gas expands outside. The movement is adequately \
described by the diffusion equation. Make the ansatz n[t,r]=t^\[Alpha] f[y], \
where y = ",
 Cell[BoxData[
  FractionBox["r", 
   SqrtBox[
    RowBox[{"4", " ", "D", " ", "t"}]]]], "Input",
  CellChangeTimes->{{3.746782948683614*^9, 3.7467829500235*^9}},
  ExpressionUUID->"c762c9d7-23ef-427d-9299-83e41097b9fc"],
 " and solve the diffusion equation."
}], "Subsubsection",
 CellChangeTimes->{{3.7467794435249662`*^9, 3.7467796251434183`*^9}, {
  3.7467797937201033`*^9, 3.746779794927183*^9}, {3.7467798570530653`*^9, 
  3.746779873325562*^9}, {3.74678279991954*^9, 3.7467828343426447`*^9}, {
  3.7467828982290487`*^9, 3.746782959986652*^9}, {3.746793447547832*^9, 
  3.746793448414773*^9}},ExpressionUUID->"dd329ca4-8b55-40fe-aa72-\
1dc93c8d5056"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"n", "[", 
     RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], "\[Equal]", 
  RowBox[{"D0", " ", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"r", "^", "2"}], " ", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"n", "[", 
          RowBox[{"t", ",", "r"}], "]"}], ",", "r"}], "]"}]}], ",", "r"}], 
     "]"}], "/", 
    RowBox[{"r", "^", "2"}]}]}]}]], "Input",
 CellChangeTimes->{{3.74678171783851*^9, 3.746781721340351*^9}, {
  3.746781752148666*^9, 
  3.746781819518137*^9}},ExpressionUUID->"4bbf46cd-177c-4546-9893-\
222924e6bfe8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["n", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "r"}], "]"}], "\[Equal]", 
     FractionBox[
      RowBox[{"D0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "r", " ", 
          RowBox[{
           SuperscriptBox["n", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "1"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "r"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["r", "2"], " ", 
          RowBox[{
           SuperscriptBox["n", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "r"}], "]"}]}]}], ")"}]}], 
      SuperscriptBox["r", "2"]]}], "/.", 
    RowBox[{"n", "\[Rule]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"#1", "^", "\[Alpha]"}], " ", 
        RowBox[{"f", "[", 
         RowBox[{"#2", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"4", " ", "D0", " ", "#1"}], "]"}]}], "]"}]}], "&"}], 
      ")"}]}]}], "/.", 
   RowBox[{"r", "\[Rule]", " ", 
    RowBox[{"2", " ", 
     RowBox[{"Sqrt", "[", 
      RowBox[{"D0", " ", "t"}], "]"}], "y"}]}]}], "//", "Simplify"}]], "Input",\

 CellChangeTimes->{{3.746781912195629*^9, 
  3.746781955849164*^9}},ExpressionUUID->"812638b5-efb0-4bb3-ab6e-\
ba2ad639929b"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox["t", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "\[Alpha]"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", "y", " ", "\[Alpha]", " ", 
       RowBox[{"f", "[", "y", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["y", "2"]}], ")"}], " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}], "+", 
      RowBox[{"y", " ", 
       RowBox[{
        SuperscriptBox["f", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "y"], 
  "\[Equal]", "0"}]], "Output",
 CellChangeTimes->{{3.746781934316442*^9, 
  3.7467819580165243`*^9}},ExpressionUUID->"ce1d1aed-c841-4487-b788-\
9e32fd8ac8ae"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{
   RowBox[{"D0", ">", "0"}], "&&", 
   RowBox[{"t", ">", "0"}], "&&", 
   RowBox[{"\[Alpha]", "<", "0"}]}]}]], "Input",
 CellChangeTimes->{{3.746782396959622*^9, 3.746782400664163*^9}, {
  3.7467824817080812`*^9, 
  3.746782498886079*^9}},ExpressionUUID->"e805508c-ccc7-4f99-b0cd-\
384a7ba55ec1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"D0", ">", "0"}], "&&", 
  RowBox[{"t", ">", "0"}], "&&", 
  RowBox[{"\[Alpha]", "<", "0"}]}]], "Output",
 CellChangeTimes->{
  3.746782402793209*^9, {3.7467824833891163`*^9, 
   3.746782499724966*^9}},ExpressionUUID->"74fe8d55-9be5-45f2-99ff-\
f0d65701d28a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sol1", "=", 
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["t", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "\[Alpha]"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "4"}], " ", "y", " ", "\[Alpha]", " ", 
            RowBox[{"f", "[", "y", "]"}]}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["y", "2"]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["f", "\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}], "+", 
           RowBox[{"y", " ", 
            RowBox[{
             SuperscriptBox["f", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "y", "]"}]}]}], ")"}]}], "y"], 
       "\[Equal]", "0"}], ",", "f", ",", "y"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"t", "^", 
       RowBox[{"(", "\[Alpha]", ")"}]}], 
      RowBox[{"f", "[", "y", "]"}]}], "/.", "%"}], "/.", 
    RowBox[{"y", "\[Rule]", " ", 
     RowBox[{"r", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"4", " ", "D0", " ", "t"}], "]"}]}]}]}], "/.", 
   RowBox[{
    RowBox[{"C", "[", "2", "]"}], "\[Rule]", " ", "0"}]}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"4", " ", "\[Pi]", " ", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"%", 
        RowBox[{"r", "^", "2"}]}], "/.", 
       RowBox[{
        RowBox[{"C", "[", "2", "]"}], "\[Rule]", " ", "0"}]}], "/.", 
      RowBox[{"\[Alpha]", "\[Rule]", " ", 
       RowBox[{"-", 
        RowBox[{"Zeta", "[", "3", "]"}]}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "\[Infinity]"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n1", "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"Zeta", "[", "3", "]"}], "\[Rule]", " ", 
     RowBox[{"-", "\[Alpha]"}]}]}], "//", "Simplify"}]}]}], "Input",
 CellChangeTimes->{{3.746781981369142*^9, 3.7467819847220907`*^9}, {
   3.746782217970703*^9, 3.7467822852131453`*^9}, {3.746782326650031*^9, 
   3.746782339630603*^9}, {3.7467824081778507`*^9, 3.746782448418531*^9}, {
   3.746782504742507*^9, 3.746782518446555*^9}, {3.746782550821892*^9, 
   3.746782630200582*^9}, 3.7467826745872087`*^9, {3.746782731171533*^9, 
   3.7467827323964043`*^9}},ExpressionUUID->"9f45d2b8-ab58-43b2-b358-\
08a273896dd3"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"-", 
     FractionBox[
      SuperscriptBox["r", "2"], 
      RowBox[{"4", " ", "D0", " ", "t"}]]}]], " ", 
   SuperscriptBox["t", "\[Alpha]"], " ", 
   SqrtBox[
    RowBox[{"D0", " ", "t"}]], " ", 
   RowBox[{"C", "[", "1", "]"}], " ", 
   RowBox[{"HermiteH", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "\[Alpha]"}], ")"}]}], ",", 
     FractionBox["r", 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{"D0", " ", "t"}]]}]]}], "]"}]}], "r"]], "Output",
 CellChangeTimes->{
  3.746781985970005*^9, {3.746782219183979*^9, 3.746782285466343*^9}, {
   3.746782331748456*^9, 3.746782340063203*^9}, {3.746782436352098*^9, 
   3.74678245010892*^9}, {3.7467824845596437`*^9, 3.746782519314179*^9}, {
   3.746782561711495*^9, 3.746782579179721*^9}, 3.746782617951721*^9, 
   3.746782733478417*^9},ExpressionUUID->"32ff2ac6-3b20-40ee-aeb8-\
92b1f3b1c61d"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{"1", "-", 
     RowBox[{"2", " ", "\[Alpha]"}]}]], " ", 
   SuperscriptBox["\[Pi]", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox["t", "\[Alpha]"], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"D0", " ", "t"}], ")"}], 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"C", "[", "1", "]"}]}], 
  RowBox[{"Gamma", "[", 
   RowBox[{
    FractionBox["5", "2"], "+", "\[Alpha]"}], "]"}]]], "Output",
 CellChangeTimes->{
  3.746781985970005*^9, {3.746782219183979*^9, 3.746782285466343*^9}, {
   3.746782331748456*^9, 3.746782340063203*^9}, {3.746782436352098*^9, 
   3.74678245010892*^9}, {3.7467824845596437`*^9, 3.746782519314179*^9}, {
   3.746782561711495*^9, 3.746782579179721*^9}, 3.746782617951721*^9, 
   3.74678273435273*^9},ExpressionUUID->"68a1b35a-9748-434c-b3bb-\
baeb993e5c5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]sol", "=", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"n1", "[", 
         RowBox[{"t", ",", "r"}], "]"}], ",", "t"}], "]"}], "\[Equal]", "0"}],
      ",", "\[Alpha]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"n0", "==", 
      RowBox[{"n1", "[", 
       RowBox[{"t", ",", "r"}], "]"}]}], "/.", "\[Alpha]sol"}], ",", 
    RowBox[{"C", "[", "1", "]"}]}], "]"}], "//", 
  "Simplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n1", "[", 
   RowBox[{"t", ",", "r"}], "]"}], "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"t", "^", 
         RowBox[{"(", "\[Alpha]", ")"}]}], 
        RowBox[{"f", "[", "y", "]"}]}], "/.", "sol1"}], "/.", 
      RowBox[{"y", "\[Rule]", " ", 
       RowBox[{"r", "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"4", " ", "D0", " ", "t"}], "]"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{"C", "[", "2", "]"}], "\[Rule]", " ", "0"}]}], "/.", 
    "\[Alpha]sol"}], "/.", 
   RowBox[{"%", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]}], "Input",
 CellChangeTimes->{{3.746782637289319*^9, 
  3.746782779245571*^9}},ExpressionUUID->"a47ac3dc-0eee-4efb-b8ef-\
762f05cced1f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    FractionBox["n0", 
     RowBox[{"16", " ", 
      SuperscriptBox["D0", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["\[Pi]", 
       RowBox[{"3", "/", "2"}]]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.746782658951857*^9, {3.746782716136969*^9, 3.74678272161581*^9}, 
   3.746782780492001*^9},ExpressionUUID->"9b1adc8c-3b03-454b-9e8e-\
0fce6b2ece63"],

Cell[BoxData[
 RowBox[{"{", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", 
      FractionBox[
       SuperscriptBox["r", "2"], 
       RowBox[{"4", " ", "D0", " ", "t"}]]}]], " ", "n0"}], 
   RowBox[{"8", " ", 
    SuperscriptBox["D0", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["\[Pi]", 
     RowBox[{"3", "/", "2"}]], " ", 
    SuperscriptBox["t", 
     RowBox[{"3", "/", "2"}]]}]], "}"}]], "Output",
 CellChangeTimes->{
  3.746782658951857*^9, {3.746782716136969*^9, 3.74678272161581*^9}, 
   3.7467827804935007`*^9},ExpressionUUID->"6aedb009-dd75-4fd6-824c-\
303545c724fd"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Game of life", "Subsection",
 CellChangeTimes->{{3.746779431556693*^9, 3.746779437749147*^9}, {
  3.746781645634516*^9, 3.7467816470099077`*^9}, {3.746782973006235*^9, 
  3.746782973874105*^9}, {3.7467834838845787`*^9, 
  3.746783485209556*^9}},ExpressionUUID->"00b72957-d4a3-4316-b100-\
4806276a554d"],

Cell[CellGroupData[{

Cell["\<\
Consider a 100x100 (periodic) lattice with binary elements (0,1) or (dead, \
alive). Implement a game of life (i.e. your own, do not use CellularAutomaton \
of Mathematica) using the following evolution rules (there are 8 neighbours \
for each cell), see Wikipedia for more details
Each living cell with 0 or 1 living neighbours will die (underpopulation). 
Each living cell with 3 or more living neighbours will die (overpopulation).
Each living cell with 2 or 3 living neighbours will live to see the next time \
step.
Each dead cell with exactly 3 living neighbours will become a living cell \
during the next time step.
Use a random initial stage and look at its evolution. What kind of patterns \
do you see?
See Wikipedia for Glider gun and construct one of your own.\
\>", "Subsubsection",
 CellChangeTimes->{{3.7467794435249662`*^9, 3.7467796251434183`*^9}, {
  3.7467797937201033`*^9, 3.746779794927183*^9}, {3.7467798570530653`*^9, 
  3.746779873325562*^9}, {3.74678279991954*^9, 3.7467828343426447`*^9}, {
  3.7467828982290487`*^9, 3.746782959986652*^9}, {3.7467834908637333`*^9, 
  3.74678350888836*^9}, {3.746784218823485*^9, 3.7467843906338587`*^9}, {
  3.7467844245006332`*^9, 3.746784483510873*^9}, {3.746788114621378*^9, 
  3.746788119816453*^9}, {3.746793573816648*^9, 3.746793698570754*^9}, {
  3.746795250245124*^9, 
  3.746795260397595*^9}},ExpressionUUID->"e8bece01-4e88-4901-a8d9-\
83d9cb8332ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Glidergun", "[", "L_", "]"}], ":=", 
   RowBox[{"SparseArray", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "2"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "2"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "3"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "3"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "12"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "12"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"8", ",", "12"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "13"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"9", ",", "13"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "14"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"10", ",", "15"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", "14"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", "15"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "16"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "18"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "19"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "18"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"8", ",", "18"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "17"}], "}"}], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"9", ",", "17"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", "22"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "22"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "22"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", "23"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "23"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"6", ",", "23"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "24"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "24"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"3", ",", "26"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"2", ",", "26"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"7", ",", "26"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"8", ",", "26"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "36"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", "36"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"4", ",", "37"}], "}"}], "\[Rule]", " ", "1"}], ",", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"5", ",", "37"}], "}"}], "\[Rule]", " ", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"L", ",", "L"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7467937179409018`*^9, 3.746793741429439*^9}, {
   3.746793780614588*^9, 3.7467937956871634`*^9}, {3.7467939874362*^9, 
   3.746794315155837*^9}, {3.746794345453508*^9, 3.746794362997813*^9}, {
   3.746794412879367*^9, 3.7467944644477*^9}, 3.746794508428486*^9, {
   3.74679455402852*^9, 3.746794741248028*^9}, {3.746794782441401*^9, 
   3.74679479144171*^9}, {3.746794937469886*^9, 3.746794962734234*^9}, {
   3.746795046487097*^9, 3.746795054576579*^9}, {3.7467951080186462`*^9, 
   3.74679515160565*^9}},ExpressionUUID->"7e9ae0bc-18ae-48f5-9314-\
167caefac69b"],

Cell["Random starter:", "Text",
 CellChangeTimes->{{3.746794759455646*^9, 
  3.7467947621673717`*^9}},ExpressionUUID->"8ba6512f-1ae7-4459-8bc6-\
4eb6397437ae"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Lx", "=", "90"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ly", "=", "90"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lattice", "=", 
   RowBox[{"RandomInteger", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Lx", ",", "Ly"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lattice2", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"Lx", ",", "Ly"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sites", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Lx"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "Lx"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7467872862861643`*^9, 3.7467873446205463`*^9}, {
   3.746788148831463*^9, 3.746788150732527*^9}, {3.74678825570582*^9, 
   3.746788300612759*^9}, {3.746790377183022*^9, 3.7467904569878902`*^9}, {
   3.746790707279188*^9, 3.746790725749262*^9}, {3.7467926587986727`*^9, 
   3.746792662471942*^9}, {3.746793038797028*^9, 3.746793041080242*^9}, {
   3.7467935060801497`*^9, 3.746793521425322*^9}, 
   3.7467947504406*^9},ExpressionUUID->"7bb9c7ab-1144-4311-b28a-cdfdff0a57fd"],

Cell["Glidergun:", "Text",
 CellChangeTimes->{{3.746794766319291*^9, 
  3.7467947676395884`*^9}},ExpressionUUID->"8d834cac-1c27-4536-855e-\
b0a3d45db729"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"L", "=", "40"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Lx", "=", "L"}], ";", 
  RowBox[{"Ly", "=", "L"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lattice", "=", 
   RowBox[{"Glidergun", "[", "L", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"lattice2", "=", 
   RowBox[{"ConstantArray", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"Lx", ",", "Ly"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sites", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "j"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "Lx"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "Lx"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.74679475493524*^9, 3.746794831033917*^9}, 
   3.746794877747569*^9},ExpressionUUID->"3506e95b-0682-4aed-9834-\
96f8ba6ad2ce"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"sitel", "[", "site_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"site", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "-", "2"}], ",", "Lx"}], "]"}], "+",
       "1"}], ",", 
     RowBox[{"site", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"siter", "[", "site_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"site", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "Lx"}], "]"}], "+", "1"}], ",", 
     
     RowBox[{"site", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"siteu", "[", "site_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"site", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"site", "[", 
         RowBox[{"[", "2", "]"}], "]"}], ",", "Ly"}], "]"}], "+", "1"}]}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"sited", "[", "site_", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"site", "[", 
      RowBox[{"[", "1", "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"site", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "-", "2"}], ",", "Ly"}], "]"}], "+",
       "1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"lat", "[", "site_", "]"}], ":=", 
   RowBox[{"lattice", "[", 
    RowBox[{"[", 
     RowBox[{
      RowBox[{"site", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", 
      RowBox[{"site", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"neighbourcount", "[", 
   RowBox[{"a1_", ",", "a2_"}], "]"}], ":=", 
  RowBox[{"neighbourcount", "[", 
   RowBox[{"{", 
    RowBox[{"a1", ",", "a2"}], "}"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"neighbourcount", "[", "site_", "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"lat", "[", 
       RowBox[{"sitel", "[", "site", "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"siter", "[", "site", "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"siteu", "[", "site", "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"sited", "[", "site", "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"sited", "[", 
        RowBox[{"sitel", "[", "site", "]"}], "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"sited", "[", 
        RowBox[{"siter", "[", "site", "]"}], "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"siteu", "[", 
        RowBox[{"siter", "[", "site", "]"}], "]"}], "]"}], "+", 
      RowBox[{"lat", "[", 
       RowBox[{"siteu", "[", 
        RowBox[{"sitel", "[", "site", "]"}], "]"}], "]"}]}], ")"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"HeavisideTheta", "[", 
        RowBox[{
         RowBox[{"lat", "[", "site", "]"}], "-", "0.5"}], "]"}]}], "-", "1"}],
      ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"updatelattice", "[", "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{
     RowBox[{"lattice2", "=", 
      RowBox[{"Apply", "[", 
       RowBox[{"neighbourcount", ",", "sites", ",", 
        RowBox[{"{", "2", "}"}]}], "]"}]}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"i", "=", "1"}], ",", 
       RowBox[{"i", "<=", "Lx"}], ",", 
       RowBox[{"i", "=", 
        RowBox[{"i", "+", "1"}]}], ",", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "<=", "Ly"}], ",", 
         RowBox[{"j", "=", 
          RowBox[{"j", "+", "1"}]}], ",", 
         RowBox[{
          RowBox[{"Which", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"lattice2", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Equal]", "0"}], "||", 
             RowBox[{
              RowBox[{"lattice2", "[", 
               RowBox[{"[", 
                RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Equal]", "1"}]}], 
            ",", 
            RowBox[{
             RowBox[{"lattice", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", "0"}], ",", 
            RowBox[{
             RowBox[{"lattice2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], ">", "3"}], ",", 
            RowBox[{
             RowBox[{"lattice", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", "0"}], ",", 
            RowBox[{
             RowBox[{"lattice2", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], "\[Equal]", 
             RowBox[{"-", "3"}]}], ",", 
            RowBox[{
             RowBox[{"lattice", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", "1"}]}], "]"}], 
          ";"}]}], "]"}]}], "]"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.746784487054146*^9, 3.746784622393145*^9}, {
  3.746784840657528*^9, 3.7467850302155027`*^9}, {3.7467881628113403`*^9, 
  3.746788176900107*^9}, {3.7467882105744123`*^9, 3.746788213192878*^9}, {
  3.746788248331073*^9, 3.746788275278428*^9}, {3.746788311101245*^9, 
  3.74678831937186*^9}, {3.74678855174406*^9, 3.7467885586384907`*^9}, {
  3.746788936291758*^9, 3.746789125607596*^9}, {3.7467892071676817`*^9, 
  3.7467892084874687`*^9}, {3.746789252161434*^9, 3.746789263628487*^9}, {
  3.746789539777924*^9, 3.7467895586716337`*^9}, {3.7467902868615294`*^9, 
  3.746790313617394*^9}, {3.7467905317404957`*^9, 3.746790531847595*^9}, {
  3.746790954512278*^9, 3.746790955963344*^9}, {3.746791337394938*^9, 
  3.746791370036875*^9}},ExpressionUUID->"e481f46e-271e-40a6-bb63-\
1e94a6f085be"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"updatelattice", "[", "]"}], ",", 
   RowBox[{"{", "200", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7467895762266283`*^9, 3.7467895847321987`*^9}, {
  3.746790547104383*^9, 3.7467905509533873`*^9}, {3.746790792480015*^9, 
  3.746790793241959*^9}},ExpressionUUID->"aac1fc0f-0fe9-4f63-a19f-\
556eebd45638"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MatrixPlot", "[", "lattice", "]"}], "//", "Dynamic"}]], "Input",
 CellChangeTimes->{{3.746789562990877*^9, 
  3.746789590421143*^9}},ExpressionUUID->"59b3f1eb-510d-4062-b72b-\
2d557930a3ef"]
}, Closed]],

Cell["\<\
Verify that your implementation is working by comparing it to \
CellularAutomaton.\
\>", "Subsubsection",
 CellChangeTimes->{{3.7467794435249662`*^9, 3.7467796251434183`*^9}, {
  3.7467797937201033`*^9, 3.746779794927183*^9}, {3.7467798570530653`*^9, 
  3.746779873325562*^9}, {3.74678279991954*^9, 3.7467828343426447`*^9}, {
  3.7467828982290487`*^9, 3.746782959986652*^9}, {3.7467834908637333`*^9, 
  3.74678350888836*^9}, {3.746784218823485*^9, 3.7467843906338587`*^9}, {
  3.7467844245006332`*^9, 3.746784483510873*^9}, {3.746788114621378*^9, 
  3.746788119816453*^9}, {3.746793573816648*^9, 3.746793698570754*^9}, {
  3.746795250245124*^9, 
  3.746795327478386*^9}},ExpressionUUID->"6e86e9d3-f4bb-4f86-97da-\
31f9520dfec3"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{894, 716},
WindowMargins->{{Automatic, 604}, {Automatic, 96}},
ShowSelection->True,
FrontEndVersion->"11.1 for Linux x86 (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 175, 3, 66, "Chapter", "ExpressionUUID" -> \
"7f1a0757-16f0-4c59-8af7-e88ba65b0135"],
Cell[CellGroupData[{
Cell[780, 29, 166, 3, 45, "Subsection", "ExpressionUUID" -> \
"5aa61a2d-627a-4487-a3a9-41effb956b18"],
Cell[CellGroupData[{
Cell[971, 36, 671, 14, 85, "Subsubsection", "ExpressionUUID" -> \
"30063435-ac33-4918-a4ae-fbf5e02acd7c"],
Cell[CellGroupData[{
Cell[1667, 54, 301, 8, 32, "Input", "ExpressionUUID" -> \
"f55084c2-5117-49a4-845e-fecbacf4fefb"],
Cell[1971, 64, 237, 7, 32, "Output", "ExpressionUUID" -> \
"b3ef5269-09e5-4d2f-85bf-ca4069b92a86"]
}, Open  ]],
Cell[2223, 74, 1714, 48, 106, "Input", "ExpressionUUID" -> \
"26be045e-bc46-490c-9394-1a6939bad5e2"],
Cell[3940, 124, 146, 3, 30, "Text", "ExpressionUUID" -> \
"aeae8beb-c612-436b-bb4c-468c878c5629"],
Cell[CellGroupData[{
Cell[4111, 131, 2189, 64, 157, "Input", "ExpressionUUID" -> \
"e027bd06-3372-4135-98df-811d3d96c0f6"],
Cell[6303, 197, 618, 15, 63, "Output", "ExpressionUUID" -> \
"926cf37b-2fa9-4808-8744-4f035b525702"]
}, Open  ]],
Cell[6936, 215, 149, 3, 31, "Text", "ExpressionUUID" -> \
"4c1061d1-1bff-404a-b93b-6a8f661a72cd"],
Cell[CellGroupData[{
Cell[7110, 222, 1161, 36, 75, "Input", "ExpressionUUID" -> \
"e6ff56e7-94bb-4b35-819c-28d8d776ef86"],
Cell[8274, 260, 1190, 38, 70, "Output", "ExpressionUUID" -> \
"54240b0d-0043-4bac-8d57-1513fc9d4eb2"]
}, Open  ]],
Cell[9479, 301, 150, 3, 30, "Text", "ExpressionUUID" -> \
"f8c99f9f-bdf9-410d-994d-57a4b4aefedb"],
Cell[9632, 306, 697, 19, 34, "Input", "ExpressionUUID" -> \
"57d36992-120a-4a5c-9213-ba131f3252c9"],
Cell[10332, 327, 156, 3, 30, "Text", "ExpressionUUID" -> \
"e62e425d-bdb7-4355-8744-8ff7017c9dbb"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[10537, 336, 212, 4, 45, "Subsection", "ExpressionUUID" -> \
"f8493287-7cd9-417b-839f-faf33a4095b2"],
Cell[CellGroupData[{
Cell[10774, 344, 914, 18, 119, "Subsubsection", "ExpressionUUID" -> \
"dd329ca4-8b55-40fe-aa72-1dc93c8d5056"],
Cell[11691, 364, 656, 21, 34, "Input", "ExpressionUUID" -> \
"4bbf46cd-177c-4546-9893-222924e6bfe8"],
Cell[CellGroupData[{
Cell[12372, 389, 1655, 54, 83, "Input", "ExpressionUUID" -> \
"812638b5-efb0-4bb3-ab6e-ba2ad639929b"],
Cell[14030, 445, 853, 26, 60, "Output", "ExpressionUUID" -> \
"ce1d1aed-c841-4487-b788-9e32fd8ac8ae"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14920, 476, 352, 9, 32, "Input", "ExpressionUUID" -> \
"e805508c-ccc7-4f99-b0cd-384a7ba55ec1"],
Cell[15275, 487, 293, 8, 32, "Output", "ExpressionUUID" -> \
"74fe8d55-9be5-45f2-99ff-f0d65701d28a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15605, 500, 2651, 74, 131, "Input", "ExpressionUUID" -> \
"9f45d2b8-ab58-43b2-b358-08a273896dd3"],
Cell[18259, 576, 1022, 28, 73, "Output", "ExpressionUUID" -> \
"32ff2ac6-3b20-40ee-aeb8-92b1f3b1c61d"],
Cell[19284, 606, 879, 23, 64, "Output", "ExpressionUUID" -> \
"68a1b35a-9748-434c-b3bb-baeb993e5c5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20200, 634, 1347, 43, 80, "Input", "ExpressionUUID" -> \
"a47ac3dc-0eee-4efb-b8ef-762f05cced1f"],
Cell[21550, 679, 484, 14, 52, "Output", "ExpressionUUID" -> \
"9b1adc8c-3b03-454b-9e8e-0fce6b2ece63"],
Cell[22037, 695, 630, 19, 67, "Output", "ExpressionUUID" -> \
"6aedb009-dd75-4fd6-824c-303545c724fd"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[22728, 721, 308, 5, 44, "Subsection", "ExpressionUUID" -> \
"00b72957-d4a3-4316-b100-4806276a554d"],
Cell[CellGroupData[{
Cell[23061, 730, 1429, 24, 275, "Subsubsection", "ExpressionUUID" -> \
"e8bece01-4e88-4901-a8d9-83d9cb8332ae"],
Cell[24493, 756, 4759, 126, 103, "Input", "ExpressionUUID" -> \
"7e9ae0bc-18ae-48f5-9314-167caefac69b"],
Cell[29255, 884, 159, 3, 30, "Text", "ExpressionUUID" -> \
"8ba6512f-1ae7-4459-8bc6-4eb6397437ae"],
Cell[29417, 889, 1408, 37, 126, "Input", "ExpressionUUID" -> \
"7bb9c7ab-1144-4311-b28a-cdfdff0a57fd"],
Cell[30828, 928, 154, 3, 31, "Text", "ExpressionUUID" -> \
"8d834cac-1c27-4536-855e-b0a3d45db729"],
Cell[30985, 933, 952, 28, 126, "Input", "ExpressionUUID" -> \
"3506e95b-0682-4aed-9834-96f8ba6ad2ce"],
Cell[31940, 963, 6148, 173, 309, "Input", "ExpressionUUID" -> \
"e481f46e-271e-40a6-bb63-1e94a6f085be"],
Cell[38091, 1138, 367, 8, 34, "Input", "ExpressionUUID" -> \
"aac1fc0f-0fe9-4f63-a19f-556eebd45638"],
Cell[38461, 1148, 225, 5, 32, "Input", "ExpressionUUID" -> \
"59b3f1eb-510d-4062-b72b-2d557930a3ef"]
}, Closed]],
Cell[38701, 1156, 738, 13, 29, "Subsubsection", "ExpressionUUID" -> \
"6e86e9d3-f4bb-4f86-97da-31f9520dfec3"]
}, Open  ]]
}, Open  ]]
}
]
*)

